package net.knarcraft.ffmpegconverter.streams;

/**
 * An object representation of a subtitle stream in a media file
 */
public class SubtitleStream extends StreamObject {
    final private String language;
    final private String title; //Title shown
    final private boolean isFullSubtitle; //Songs and signs will be false
    final private boolean isImageSubtitle;

    public SubtitleStream(String codecName, int absoluteIndex, int relativeIndex, String language, String title) {
        this.codecType = "subtitle";
        this.codecName = codecName;
        this.absoluteIndex = absoluteIndex;
        this.language = language;
        this.title = title;
        this.isFullSubtitle = isFullSubtitle();
        this.relativeIndex = relativeIndex;
        this.isImageSubtitle = isImageSubtitle();
    }

    /**
     * Checks whether a subtitle is image based (as opposed to text based)
     * @return True if the subtitle is image based
     */
    private boolean isImageSubtitle() {
        return codecName != null && getCodecName().equals("hdmv_pgs_subtitle");
    }

    /**
     * Checks whether translates everything (as opposed to just songs and signs)
     * @return True if the subtitles translate everything
     */
    private boolean isFullSubtitle() {
        if (getTitle() == null) {
            return false;
        }
        String titleLowercase = getTitle().toLowerCase();
        return !titleLowercase.matches("signs?[ &\\/a-z]+songs?") &&
                !titleLowercase.matches("songs?[ &\\/a-z]+signs?") &&
                !titleLowercase.matches("forced");
    }

    public String getLanguage() {
        return this.language;
    }

    public String getTitle() {
        return this.title;
    }

    public boolean getIsImageSubtitle() {
        return this.isImageSubtitle;
    }

    public boolean getIsFullSubtitle() {
        return this.isFullSubtitle;
    }
}